==> matrix_sdk-0.1.5.tar.gz: lib/src/store.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/event.dart';
import 'package:matrix_sdk/src/homeserver.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/user.dart';

/// Stores all data (rooms, users, events) somewhere.
abstract class Store {

  bool get isOpen;

  Future<bool> open({LocalUser user});
  Future<void> close();

  Future<UserId> getUserId();
  Future<void> setUserId(UserId value);

  Future<String> getAccessToken();
  Future<void> setAccessToken(String value);

  Future<String> getSyncToken();
  Future<void> setSyncToken(String value);

  Future<Homeserver> getHomeserver();
  Future<void> setHomeserver(Homeserver value);

  Future<JoinedRoom> getJoinedRoom(RoomId id);
  Future<void> setJoinedRoom(RoomId id, JoinedRoom room);

  Stream<JoinedRoom> getJoinedRooms();

  Future<Event> getEvent(RoomId roomId, EventId id);
  Stream<Event> getEvents(RoomId id);
  Future<void> addEvent(RoomId roomId, Event event);
  Future<void> addEvents(RoomId roomId, List<Event> events);
}

==> matrix_sdk-0.2.0.tar.gz: lib/src/store.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/event.dart';
import 'package:matrix_sdk/src/homeserver.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/user.dart';

/// Stores all data (rooms, users, events) somewhere.
abstract class Store {

  bool get isOpen;

  Future<bool> open({LocalUser user});
  Future<void> close();

  Future<UserId> getUserId();
  Future<void> setUserId(UserId value);

  Future<String> getAccessToken();
  Future<void> setAccessToken(String value);

  Future<String> getSyncToken();
  Future<void> setSyncToken(String value);

  Future<Homeserver> getHomeserver();
  Future<void> setHomeserver(Homeserver value);

  Future<JoinedRoom> getJoinedRoom(RoomId id);
  Future<void> setJoinedRooms(Iterable<JoinedRoom> rooms);
  Stream<JoinedRoom> getJoinedRooms();

  Future<Event> getEvent(Room room, EventId id);
  Stream<Event> getEvents(Room id);
  Future<void> addEvents(Room room, Iterable<Event> events);

  Future<User> getMember(RoomId roomId, UserId id);
  Stream<User> getMembers(RoomId id);
  Future<void> addMembers(RoomId roomId, Iterable<User> members);
}
